@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 
-from agora.base import ParametersABC, ProcessABC
+from agora.abc import ParametersABC, ProcessABC
 
 
 class TemplateParameters(ParametersABC):
